use thiserror::Error;

#[derive(Error, Debug)]
pub enum WorkOSError {
    #[error("identifier `{0}` not found")]
    NotFound(String),
    #[error("unknown error")]
    Unknown(#[from] anyhow::Error),
}
